#!/bin/sh

set -e

if [ -d /usr/share/doc/confget/examples ]; then
	export MANPAGE='/usr/share/man/man1/confget.1.gz'
	export TESTDIR='/usr/share/doc/confget/examples/tests'
else
	export TESTDIR='t'
fi

exec "$@"
